==> huaweicloudsdkevs-3.0.5b0-py3-none-any.whl: huaweicloudsdkevs/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import EvsClient
from huaweicloudsdkevs.v2.evs_client import EvsClient
from huaweicloudsdkevs.v2.evs_async_client import EvsAsyncClient
# import models into sdk package
from huaweicloudsdkevs.v2.model.attachment import Attachment
from huaweicloudsdkevs.v2.model.az_info import AzInfo
from huaweicloudsdkevs.v2.model.batch_create_volume_tags_request import BatchCreateVolumeTagsRequest
from huaweicloudsdkevs.v2.model.batch_create_volume_tags_request_body import BatchCreateVolumeTagsRequestBody
from huaweicloudsdkevs.v2.model.batch_create_volume_tags_response import BatchCreateVolumeTagsResponse
from huaweicloudsdkevs.v2.model.batch_delete_volume_tags_request import BatchDeleteVolumeTagsRequest
from huaweicloudsdkevs.v2.model.batch_delete_volume_tags_request_body import BatchDeleteVolumeTagsRequestBody
from huaweicloudsdkevs.v2.model.batch_delete_volume_tags_response import BatchDeleteVolumeTagsResponse
from huaweicloudsdkevs.v2.model.bss_param_for_create_volume import BssParamForCreateVolume
from huaweicloudsdkevs.v2.model.bss_param_for_resize_volume import BssParamForResizeVolume
from huaweicloudsdkevs.v2.model.cinder_export_to_image_option import CinderExportToImageOption
from huaweicloudsdkevs.v2.model.cinder_export_to_image_request import CinderExportToImageRequest
from huaweicloudsdkevs.v2.model.cinder_export_to_image_request_body import CinderExportToImageRequestBody
from huaweicloudsdkevs.v2.model.cinder_export_to_image_response import CinderExportToImageResponse
from huaweicloudsdkevs.v2.model.cinder_list_availability_zones_request import CinderListAvailabilityZonesRequest
from huaweicloudsdkevs.v2.model.cinder_list_availability_zones_response import CinderListAvailabilityZonesResponse
from huaweicloudsdkevs.v2.model.cinder_list_quotas_request import CinderListQuotasRequest
from huaweicloudsdkevs.v2.model.cinder_list_quotas_response import CinderListQuotasResponse
from huaweicloudsdkevs.v2.model.cinder_list_volume_types_request import CinderListVolumeTypesRequest
from huaweicloudsdkevs.v2.model.cinder_list_volume_types_response import CinderListVolumeTypesResponse
from huaweicloudsdkevs.v2.model.create_snapshot_option import CreateSnapshotOption
from huaweicloudsdkevs.v2.model.create_snapshot_request import CreateSnapshotRequest
from huaweicloudsdkevs.v2.model.create_snapshot_request_body import CreateSnapshotRequestBody
from huaweicloudsdkevs.v2.model.create_snapshot_response import CreateSnapshotResponse
from huaweicloudsdkevs.v2.model.create_volume_option import CreateVolumeOption
from huaweicloudsdkevs.v2.model.create_volume_request import CreateVolumeRequest
from huaweicloudsdkevs.v2.model.create_volume_request_body import CreateVolumeRequestBody
from huaweicloudsdkevs.v2.model.create_volume_response import CreateVolumeResponse
from huaweicloudsdkevs.v2.model.delete_snapshot_request import DeleteSnapshotRequest
from huaweicloudsdkevs.v2.model.delete_snapshot_response import DeleteSnapshotResponse
from huaweicloudsdkevs.v2.model.delete_tags_option import DeleteTagsOption
from huaweicloudsdkevs.v2.model.delete_volume_request import DeleteVolumeRequest
from huaweicloudsdkevs.v2.model.delete_volume_response import DeleteVolumeResponse
from huaweicloudsdkevs.v2.model.image import Image
from huaweicloudsdkevs.v2.model.image_metadata import ImageMetadata
from huaweicloudsdkevs.v2.model.job_entities import JobEntities
from huaweicloudsdkevs.v2.model.link import Link
from huaweicloudsdkevs.v2.model.list_snapshots_details_request import ListSnapshotsDetailsRequest
from huaweicloudsdkevs.v2.model.list_snapshots_details_response import ListSnapshotsDetailsResponse
from huaweicloudsdkevs.v2.model.list_volume_tags_request import ListVolumeTagsRequest
from huaweicloudsdkevs.v2.model.list_volume_tags_response import ListVolumeTagsResponse
from huaweicloudsdkevs.v2.model.list_volumes_by_tags_request import ListVolumesByTagsRequest
from huaweicloudsdkevs.v2.model.list_volumes_by_tags_request_body import ListVolumesByTagsRequestBody
from huaweicloudsdkevs.v2.model.list_volumes_by_tags_response import ListVolumesByTagsResponse
from huaweicloudsdkevs.v2.model.list_volumes_details_request import ListVolumesDetailsRequest
from huaweicloudsdkevs.v2.model.list_volumes_details_response import ListVolumesDetailsResponse
from huaweicloudsdkevs.v2.model.list_volumes_details_response_body import ListVolumesDetailsResponseBody
from huaweicloudsdkevs.v2.model.match import Match
from huaweicloudsdkevs.v2.model.os_extend import OsExtend
from huaweicloudsdkevs.v2.model.quota_detail import QuotaDetail
from huaweicloudsdkevs.v2.model.quota_list import QuotaList
from huaweicloudsdkevs.v2.model.resize_volume_request import ResizeVolumeRequest
from huaweicloudsdkevs.v2.model.resize_volume_request_body import ResizeVolumeRequestBody
from huaweicloudsdkevs.v2.model.resize_volume_response import ResizeVolumeResponse
from huaweicloudsdkevs.v2.model.resource import Resource
from huaweicloudsdkevs.v2.model.rollback_info import RollbackInfo
from huaweicloudsdkevs.v2.model.rollback_snapshot_option import RollbackSnapshotOption
from huaweicloudsdkevs.v2.model.rollback_snapshot_request import RollbackSnapshotRequest
from huaweicloudsdkevs.v2.model.rollback_snapshot_request_body import RollbackSnapshotRequestBody
from huaweicloudsdkevs.v2.model.rollback_snapshot_response import RollbackSnapshotResponse
from huaweicloudsdkevs.v2.model.show_job_request import ShowJobRequest
from huaweicloudsdkevs.v2.model.show_job_response import ShowJobResponse
from huaweicloudsdkevs.v2.model.show_snapshot_request import ShowSnapshotRequest
from huaweicloudsdkevs.v2.model.show_snapshot_response import ShowSnapshotResponse
from huaweicloudsdkevs.v2.model.show_volume_request import ShowVolumeRequest
from huaweicloudsdkevs.v2.model.show_volume_response import ShowVolumeResponse
from huaweicloudsdkevs.v2.model.show_volume_tags_request import ShowVolumeTagsRequest
from huaweicloudsdkevs.v2.model.show_volume_tags_response import ShowVolumeTagsResponse
from huaweicloudsdkevs.v2.model.snapshot_details import SnapshotDetails
from huaweicloudsdkevs.v2.model.snapshot_list import SnapshotList
from huaweicloudsdkevs.v2.model.sub_job import SubJob
from huaweicloudsdkevs.v2.model.sub_job_entities import SubJobEntities
from huaweicloudsdkevs.v2.model.tag import Tag
from huaweicloudsdkevs.v2.model.tags_for_list_volumes import TagsForListVolumes
from huaweicloudsdkevs.v2.model.update_snapshot_option import UpdateSnapshotOption
from huaweicloudsdkevs.v2.model.update_snapshot_request import UpdateSnapshotRequest
from huaweicloudsdkevs.v2.model.update_snapshot_request_body import UpdateSnapshotRequestBody
from huaweicloudsdkevs.v2.model.update_snapshot_response import UpdateSnapshotResponse
from huaweicloudsdkevs.v2.model.update_volume_option import UpdateVolumeOption
from huaweicloudsdkevs.v2.model.update_volume_request import UpdateVolumeRequest
from huaweicloudsdkevs.v2.model.update_volume_request_body import UpdateVolumeRequestBody
from huaweicloudsdkevs.v2.model.update_volume_response import UpdateVolumeResponse
from huaweicloudsdkevs.v2.model.volume_attachment import VolumeAttachment
from huaweicloudsdkevs.v2.model.volume_detail import VolumeDetail
from huaweicloudsdkevs.v2.model.volume_metadata import VolumeMetadata
from huaweicloudsdkevs.v2.model.volume_type import VolumeType
from huaweicloudsdkevs.v2.model.volume_type_extra_specs import VolumeTypeExtraSpecs
from huaweicloudsdkevs.v2.model.zone_state import ZoneState

==> huaweicloudsdkevs-3.0.8b0-py3-none-any.whl: huaweicloudsdkevs/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import EvsClient
from huaweicloudsdkevs.v2.evs_client import EvsClient
from huaweicloudsdkevs.v2.evs_async_client import EvsAsyncClient
# import models into sdk package
from huaweicloudsdkevs.v2.model.attachment import Attachment
from huaweicloudsdkevs.v2.model.az_info import AzInfo
from huaweicloudsdkevs.v2.model.batch_create_volume_tags_request import BatchCreateVolumeTagsRequest
from huaweicloudsdkevs.v2.model.batch_create_volume_tags_request_body import BatchCreateVolumeTagsRequestBody
from huaweicloudsdkevs.v2.model.batch_create_volume_tags_response import BatchCreateVolumeTagsResponse
from huaweicloudsdkevs.v2.model.batch_delete_volume_tags_request import BatchDeleteVolumeTagsRequest
from huaweicloudsdkevs.v2.model.batch_delete_volume_tags_request_body import BatchDeleteVolumeTagsRequestBody
from huaweicloudsdkevs.v2.model.batch_delete_volume_tags_response import BatchDeleteVolumeTagsResponse
from huaweicloudsdkevs.v2.model.bss_param_for_create_volume import BssParamForCreateVolume
from huaweicloudsdkevs.v2.model.bss_param_for_resize_volume import BssParamForResizeVolume
from huaweicloudsdkevs.v2.model.cinder_export_to_image_option import CinderExportToImageOption
from huaweicloudsdkevs.v2.model.cinder_export_to_image_request import CinderExportToImageRequest
from huaweicloudsdkevs.v2.model.cinder_export_to_image_request_body import CinderExportToImageRequestBody
from huaweicloudsdkevs.v2.model.cinder_export_to_image_response import CinderExportToImageResponse
from huaweicloudsdkevs.v2.model.cinder_list_availability_zones_request import CinderListAvailabilityZonesRequest
from huaweicloudsdkevs.v2.model.cinder_list_availability_zones_response import CinderListAvailabilityZonesResponse
from huaweicloudsdkevs.v2.model.cinder_list_quotas_request import CinderListQuotasRequest
from huaweicloudsdkevs.v2.model.cinder_list_quotas_response import CinderListQuotasResponse
from huaweicloudsdkevs.v2.model.cinder_list_volume_types_request import CinderListVolumeTypesRequest
from huaweicloudsdkevs.v2.model.cinder_list_volume_types_response import CinderListVolumeTypesResponse
from huaweicloudsdkevs.v2.model.create_snapshot_option import CreateSnapshotOption
from huaweicloudsdkevs.v2.model.create_snapshot_request import CreateSnapshotRequest
from huaweicloudsdkevs.v2.model.create_snapshot_request_body import CreateSnapshotRequestBody
from huaweicloudsdkevs.v2.model.create_snapshot_response import CreateSnapshotResponse
from huaweicloudsdkevs.v2.model.create_volume_option import CreateVolumeOption
from huaweicloudsdkevs.v2.model.create_volume_request import CreateVolumeRequest
from huaweicloudsdkevs.v2.model.create_volume_request_body import CreateVolumeRequestBody
from huaweicloudsdkevs.v2.model.create_volume_response import CreateVolumeResponse
from huaweicloudsdkevs.v2.model.delete_snapshot_request import DeleteSnapshotRequest
from huaweicloudsdkevs.v2.model.delete_snapshot_response import DeleteSnapshotResponse
from huaweicloudsdkevs.v2.model.delete_tags_option import DeleteTagsOption
from huaweicloudsdkevs.v2.model.delete_volume_request import DeleteVolumeRequest
from huaweicloudsdkevs.v2.model.delete_volume_response import DeleteVolumeResponse
from huaweicloudsdkevs.v2.model.image import Image
from huaweicloudsdkevs.v2.model.job_entities import JobEntities
from huaweicloudsdkevs.v2.model.link import Link
from huaweicloudsdkevs.v2.model.list_snapshots_details_request import ListSnapshotsDetailsRequest
from huaweicloudsdkevs.v2.model.list_snapshots_details_response import ListSnapshotsDetailsResponse
from huaweicloudsdkevs.v2.model.list_volume_tags_request import ListVolumeTagsRequest
from huaweicloudsdkevs.v2.model.list_volume_tags_response import ListVolumeTagsResponse
from huaweicloudsdkevs.v2.model.list_volumes_by_tags_request import ListVolumesByTagsRequest
from huaweicloudsdkevs.v2.model.list_volumes_by_tags_request_body import ListVolumesByTagsRequestBody
from huaweicloudsdkevs.v2.model.list_volumes_by_tags_response import ListVolumesByTagsResponse
from huaweicloudsdkevs.v2.model.list_volumes_details_request import ListVolumesDetailsRequest
from huaweicloudsdkevs.v2.model.list_volumes_details_response import ListVolumesDetailsResponse
from huaweicloudsdkevs.v2.model.match import Match
from huaweicloudsdkevs.v2.model.os_extend import OsExtend
from huaweicloudsdkevs.v2.model.quota_detail import QuotaDetail
from huaweicloudsdkevs.v2.model.quota_detail_backup_gigabytes import QuotaDetailBackupGigabytes
from huaweicloudsdkevs.v2.model.quota_detail_backups import QuotaDetailBackups
from huaweicloudsdkevs.v2.model.quota_detail_gigabytes import QuotaDetailGigabytes
from huaweicloudsdkevs.v2.model.quota_detail_gigabytes_gpssd import QuotaDetailGigabytesGPSSD
from huaweicloudsdkevs.v2.model.quota_detail_gigabytes_sas import QuotaDetailGigabytesSAS
from huaweicloudsdkevs.v2.model.quota_detail_gigabytes_sata import QuotaDetailGigabytesSATA
from huaweicloudsdkevs.v2.model.quota_detail_gigabytes_ssd import QuotaDetailGigabytesSSD
from huaweicloudsdkevs.v2.model.quota_detail_per_volume_gigabytes import QuotaDetailPerVolumeGigabytes
from huaweicloudsdkevs.v2.model.quota_detail_snapshots import QuotaDetailSnapshots
from huaweicloudsdkevs.v2.model.quota_detail_snapshots_gpssd import QuotaDetailSnapshotsGPSSD
from huaweicloudsdkevs.v2.model.quota_detail_snapshots_sas import QuotaDetailSnapshotsSAS
from huaweicloudsdkevs.v2.model.quota_detail_snapshots_sata import QuotaDetailSnapshotsSATA
from huaweicloudsdkevs.v2.model.quota_detail_snapshots_ssd import QuotaDetailSnapshotsSSD
from huaweicloudsdkevs.v2.model.quota_detail_volumes import QuotaDetailVolumes
from huaweicloudsdkevs.v2.model.quota_detail_volumes_gpssd import QuotaDetailVolumesGPSSD
from huaweicloudsdkevs.v2.model.quota_detail_volumes_sas import QuotaDetailVolumesSAS
from huaweicloudsdkevs.v2.model.quota_detail_volumes_sata import QuotaDetailVolumesSATA
from huaweicloudsdkevs.v2.model.quota_detail_volumes_ssd import QuotaDetailVolumesSSD
from huaweicloudsdkevs.v2.model.quota_list import QuotaList
from huaweicloudsdkevs.v2.model.resize_volume_request import ResizeVolumeRequest
from huaweicloudsdkevs.v2.model.resize_volume_request_body import ResizeVolumeRequestBody
from huaweicloudsdkevs.v2.model.resize_volume_response import ResizeVolumeResponse
from huaweicloudsdkevs.v2.model.resource import Resource
from huaweicloudsdkevs.v2.model.rollback_info import RollbackInfo
from huaweicloudsdkevs.v2.model.rollback_snapshot_option import RollbackSnapshotOption
from huaweicloudsdkevs.v2.model.rollback_snapshot_request import RollbackSnapshotRequest
from huaweicloudsdkevs.v2.model.rollback_snapshot_request_body import RollbackSnapshotRequestBody
from huaweicloudsdkevs.v2.model.rollback_snapshot_response import RollbackSnapshotResponse
from huaweicloudsdkevs.v2.model.show_job_request import ShowJobRequest
from huaweicloudsdkevs.v2.model.show_job_response import ShowJobResponse
from huaweicloudsdkevs.v2.model.show_snapshot_request import ShowSnapshotRequest
from huaweicloudsdkevs.v2.model.show_snapshot_response import ShowSnapshotResponse
from huaweicloudsdkevs.v2.model.show_volume_request import ShowVolumeRequest
from huaweicloudsdkevs.v2.model.show_volume_response import ShowVolumeResponse
from huaweicloudsdkevs.v2.model.show_volume_tags_request import ShowVolumeTagsRequest
from huaweicloudsdkevs.v2.model.show_volume_tags_response import ShowVolumeTagsResponse
from huaweicloudsdkevs.v2.model.snapshot_details import SnapshotDetails
from huaweicloudsdkevs.v2.model.snapshot_list import SnapshotList
from huaweicloudsdkevs.v2.model.sub_job import SubJob
from huaweicloudsdkevs.v2.model.sub_job_entities import SubJobEntities
from huaweicloudsdkevs.v2.model.tag import Tag
from huaweicloudsdkevs.v2.model.tags_for_list_volumes import TagsForListVolumes
from huaweicloudsdkevs.v2.model.update_snapshot_option import UpdateSnapshotOption
from huaweicloudsdkevs.v2.model.update_snapshot_request import UpdateSnapshotRequest
from huaweicloudsdkevs.v2.model.update_snapshot_request_body import UpdateSnapshotRequestBody
from huaweicloudsdkevs.v2.model.update_snapshot_response import UpdateSnapshotResponse
from huaweicloudsdkevs.v2.model.update_volume_option import UpdateVolumeOption
from huaweicloudsdkevs.v2.model.update_volume_request import UpdateVolumeRequest
from huaweicloudsdkevs.v2.model.update_volume_request_body import UpdateVolumeRequestBody
from huaweicloudsdkevs.v2.model.update_volume_response import UpdateVolumeResponse
from huaweicloudsdkevs.v2.model.volume_detail import VolumeDetail
from huaweicloudsdkevs.v2.model.volume_metadata import VolumeMetadata
from huaweicloudsdkevs.v2.model.volume_type import VolumeType
from huaweicloudsdkevs.v2.model.volume_type_extra_specs import VolumeTypeExtraSpecs
from huaweicloudsdkevs.v2.model.zone_state import ZoneState
